@@ -21,7 +21,7 @@ import kb
 from arith import Number, Arith
 from thing import Thing
 from state import State
-from prop import Proposition, Prop
+from prop import Fact, Fact
 from time import Time, Instant, Duration, Finish, During, Coincide, MinComStart, MaxComEnd, Intersection
 from rule import Rule
 from metanl import Remove, Equals
