@@ -19,14 +19,15 @@
 import os
 import itertools
 #import re
+import clips
 
 from nl.exceptions import Paradox
 from nl.log import here, logger
-from nl.utils import clips, subclasses, Name, varpat
+from nl.utils import subclasses, Name, varpat
 from nl.thing import Thing
 from nl.state import State
 from nl.time import Time
-from nl.prop import Proposition
+from nl.prop import Fact
 from nl.rule import Rule
 
 
@@ -93,10 +94,10 @@ def ask_objs(*sentences):
         for ins in clps:
             if isinstance(sentence, Thing):
                 sens.append(Thing.from_clips(ins))
-            elif isinstance(sentence, Proposition):
+            elif isinstance(sentence, Fact):
                 i = clips.FindInstance(ins)
-                if issubclass(subclasses[str(i.Class.Name)], Proposition):
-                    sens.append(Proposition.from_clips(ins))
+                if issubclass(subclasses[str(i.Class.Name)], Fact):
+                    sens.append(Fact.from_clips(ins))
     return sens
 
 
@@ -115,14 +116,3 @@ def extend():
     logger.info('----------runned: %d---------------------' % acts)
     return acts
 
-# _pred_pat = re.compile('[()\s\[\]]')
-# def make_pred(classname, slots):
-#     key = classname + re.sub(_pred_pat, '', slots)
-#     clp_pred = clips.FindInstance(key)
-#     if not clp_pred:
-#         clp = 'make-instance [%s] of %s %s' % (key, classname, slots)
-#         clp_pred = clips.Eval(clp)
-#     return clp_pred
-# 
-# clips.RegisterPythonFunction(make_pred)
-
