@@ -16,9 +16,10 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with ln.  If not, see <http://www.gnu.org/licenses/>.
 
+import clips
 # import logging
-from log import logger
-from nl.utils import clips, register, Name, varpat, subclasses
+from nl.log import logger
+from nl.utils import register, Name, varpat, subclasses
 from nl.arith import Number
 from nl.time import Time, Instant
 from nl.thing import Thing
@@ -26,13 +27,10 @@ from nl.state import State
 
 _m = []
 
-class Proposition(Name):
+class Fact(Name):
     """
     """
-    clp = '(defclass Proposition (is-a Name) (slot truth (type INTEGER) (default 1) (pattern-match reactive)) (slot subject (type INSTANCE) (pattern-match reactive)) (slot predicate (type INSTANCE) (pattern-match reactive)) (slot time (type ?VARIABLE) (pattern-match reactive)))'
-    logger.info(clp)
-    clips.Build(clp)
-    _v_clips_class = clips.FindClass('Proposition')
+    _v_clips_class = clips.FindClass('Fact')
 
     def __init__(self, subj, pred, time=Instant('now'), truth=1):
         self.truth = truth
@@ -55,7 +53,7 @@ class Proposition(Name):
         p = State.from_clips(instance.GetSlot('predicate'))
         t = Time.from_clips(instance.GetSlot('time'))
         truth = instance.GetSlot('truth')
-        return Prop(s, p, t, truth=truth)
+        return Fact(s, p, t, truth=truth)
 
     def negate(self):
         self.truth = not self.truth and 1 or 0
@@ -83,7 +81,7 @@ class Proposition(Name):
         """
         put proposition in clips as a conditional element of a rule
         """
-        ce = '(logical (object (is-a Proposition) (subject %s) (predicate %s) (time %s) (truth %s)))'
+        ce = '(logical (object (is-a Fact) (subject %s) (predicate %s) (time %s) (truth %s)))'
         return ce % (self.subject.get_slot_constraint(vrs),
                      self.predicate.get_slot_constraint(vrs),
                      self.time.get_slot_constraint(vrs),
@@ -113,27 +111,4 @@ class Proposition(Name):
                                 queries and queries[0] or 'TRUE')
         return q
 
-register('Proposition', Proposition)
-Prop = Proposition
-
-_add_prop = '''
-(deffunction add-prop (?s ?p ?t ?r)
-       (bind ?count 0)
-       (do-for-all-instances ((?prop Proposition))
-                          (and (eq ?prop:subject ?s)
-                               (eq ?prop:predicate ?p)
-                               (or (and (eq (class ?t) Duration)
-                                        (= (send (send ?prop get-time) get-start) (send ?t get-start))
-                                        (= (send (send ?prop get-time) get-end) (send ?t get-end)))
-                                   (= ?prop:time ?t))
-                               (= ?prop:truth ?r))
-               (bind ?count (+ ?count 1)))
-        (if (= ?count 0)
-        then (make-instance of Proposition (subject ?s)
-                                           (predicate ?p)
-                                           (time ?t)
-                                           (truth ?r))
-        else (return TRUE)))'''
-
-logger.info(_add_prop)
-clips.Build(_add_prop)
+register('Fact', Fact)
