@@ -16,15 +16,11 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with ln.  If not, see <http://www.gnu.org/licenses/>.
 
+import clips
 from nl.log import logger
-from nl.utils import register, clips, varpat, class_constraint, Name, clips_instance
+from nl.clps import class_constraint
+from nl.utils import register, varpat, Name, clips_instance, subclasses, _newvar
 
-_vn = 0
-
-def _newvar():
-    global _vn
-    _vn += 1
-    return 'Y%d' % _vn
 
 class MetaThing(type):
     """
@@ -57,6 +53,10 @@ class Thing(Name):
     def __repr__(self):
         return '%s is a %s' % (self.value, self.__class__.__name__)
 
+    @classmethod
+    def from_clips(cls, instance):
+        return cls(str(instance))
+
     def get_ce(self, vrs):
         """
         build CE for clips
@@ -73,30 +73,13 @@ class Thing(Name):
         for a slot constraint for a pred in a prop in a rule
         """
         if varpat.match(self.value):
-            if self.value in vrs:
-                if vrs[self.value]:
-                    return '?%(val)s&:(eq ?%(val)s %(var)s)' % {'val': self.value,
-                                           'var': clips_instance(*(vrs[self.value]))}
-                else:
-                    return '?%s' % self.value
-            else:
-                vrs[self.value]= ()
-                return class_constraint % {'val': self.value,
-                                           'cls': self.__class__.__name__}
+            return self.get_var_slot_constraint(vrs, self.value)
         return '[%s]' % self.value
 
     def get_constraint(self, vrs, ancestor, mod_path):
         ci = clips_instance(ancestor, mod_path)
-        constraint = ''
         if varpat.match(self.value):
-            if self.value in vrs:
-                if vrs[self.value]:
-                    v_ci = clips_instance(*(vrs[self.value]))
-                    constraint = '&:(eq %s %s)' % (v_ci, ci)
-                else:
-                    constraint = '&:(eq %s ?%s)' % (ci, self.value)
-            else:
-                vrs[self.value] = (ancestor, mod_path)
+            constraint = self.get_var_constraint(vrs, ancestor, mod_path, ci)
         else:
             constraint = '&:(eq %s [%s])' % (ci, self.value)
         return constraint
@@ -109,33 +92,30 @@ class Thing(Name):
         if varpat.match(self.value):
             if self.value in vrs and vrs[self.value]:
                 newvar = _newvar()
-                templs.append('(?%s %s)' % (newvar,
-                                        self.__class__.__name__))
+                templs.append((newvar, self.__class__.__name__))
                 queries.append('(eq ?%s %s)' % (newvar,
                                      clips_instance(*(vrs[self.value]))))
                 return '?%s' % newvar
+            vrs[self.value] = ()
             return '?%s' % self.value
         else:
             return '[%s]' % self.value
 
-    def get_ism(self,  templs, queries, newvar='sen'):
+    def get_ism(self,  templs, queries, vrs, newvar='sen'):
         """
         get instance-set method;
         return (instance-set templates, instance-set queries)
         """
         if varpat.match(self.value):
-            templs.append('(?%s %s)' % (self.value,
-                                        self.__class__.__name__))
+            templs.append((self.value, self.__class__.__name__))
+            vrs[self.value] = ()
         else:
-            templs.append('(?%s %s)' % (newvar, self.__class__.__name__))
+            templs.append((newvar, self.__class__.__name__))
             queries.append('(eq ?%s [%s])' % (newvar, self.value))
 
     def put(self, vrs):
         if varpat.match(self.value):
-            if self.value in vrs and vrs[self.value]:
-                return clips_instance(*(vrs[self.value]))
-            else:
-                return '?%s' % self.value
+            return self.put_var(vrs)
         else:
             return '[%s]' % self.value
 
@@ -151,12 +131,13 @@ class Thing(Name):
         queries = []
         self.get_ism(templs, queries, newvar='sen')
         if len(queries) > 1:
-            q = '(do-for-all-instances (%s) (and %s) (send ?sen delete))' % (' '.join(templs),
+            q = '(do-for-all-instances (%s) (and %s) (send ?sen delete))' % \
+                       (' '.join(['(?%s %s)' % templ for templ in templs]),
                                                         ' '.join(queries))
         else:
-            q = '(do-for-all-instances (%s) %s (send ?sen delete))' % (' '.join(templs),
+            q = '(do-for-all-instances (%s) %s (send ?sen delete))' % \
+                  (' '.join(['(?%s %s)' % templ for templ in templs]),
                                                 queries and queries[0] or 'TRUE')
         return q
 
 register('Thing', Thing)
-
