@@ -18,40 +18,31 @@
 # utils module
 
 import re
-from persistent import Persistent
 
 import clips
 from nl.log import logger
-
-clips.DebugConfig.ExternalTraceback = True
+from nl.clps import class_constraint
 
 # vars are always XNUM
 varpat = re.compile(r'^[A-Z]\w*\d+$')
 
-class_constraint = '?%(val)s&:(or (eq (class ?%(val)s) %(cls)s) (subclassp (class ?%(val)s) %(cls)s))'
-_name_def = '(defclass Name (is-a USER))'
-_reduce_class = '''
-(deffunction reduce-class (?instance ?class)
-    (if (eq (length$
-                (find-all-instances ((?a ?class))(eq (instance-name ?a) ?instance)))
-             0)
-    then (make-instance ?instance of ?class)
-    else (return TRUE)))'''
+_vn = 0
 
-clips.Build(_name_def)
-clips.Build(_reduce_class)
-#clips.Build(_del_daemon)
-logger.info(_name_def)
-logger.info(_reduce_class)
-#logger.info(_del_daemon)
+def _newvar():
+    global _vn
+    _vn += 1
+    return 'Y%d' % _vn
 
 
 subclasses = {}
 def register(clsname, cls):
     subclasses[clsname] = cls
 
+def get_class(cls):
+    return isinstance(cls, str) and subclasses[cls] or cls
 
-class Name(Persistent):
+
+class Name(object):
     """
     """
     _v_clips_class = clips.FindClass('Name')
@@ -108,3 +99,5 @@ def clips_instance(ancestor, mod_path):
         ancestor = send_str % (ancestor, mod)
         send_str = '(send %s get-%s)'
     return ancestor
+
+
